# python-uhid

![checks](https://github.com/FFY00/python-uhid/workflows/checks/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/python-uhid/badge/?version=latest)](https://python-uhid.readthedocs.io/en/latest/?badge=latest)

Pure Python typed UHID wrapper

UHID is a Linux API to create virtual HID devices.
See the [official UHID documentation](https://www.kernel.org/doc/Documentation/hid/uhid.txt).
